@@ -34,7 +34,6 @@ statusicon_css_string = """
     padding-bottom: 0;
     padding-right: 2px;
 }
-
 .statuswidget-vertical {
     border: none;
     padding-top: 2px;
@@ -73,7 +72,6 @@ class StatusWidget(Gtk.ToggleButton):
         self.box = Gtk.Box(orientation=Gtk.Orientation.HORIZONTAL)
 
         self.image = Gtk.Image(hexpand=True)
-        self.image.show()
         self.label = Gtk.Label(no_show_all=True)
         self.box.pack_start(self.image, True, False, 0)
         self.box.pack_start(self.label, False, False, 0)
@@ -84,6 +82,8 @@ class StatusWidget(Gtk.ToggleButton):
         self.set_relief(Gtk.ReliefStyle.NONE)
         self.set_focus_on_click(False)
 
+        self.show_all()
+
         flags = GObject.BindingFlags.DEFAULT | GObject.BindingFlags.SYNC_CREATE
 
         self.proxy.bind_property("label", self.label, "label", flags)
@@ -104,8 +104,6 @@ class StatusWidget(Gtk.ToggleButton):
         self.update_orientation()
         self.update_icon()
 
-        self.show_all()
-
     def _on_icon_name_changed(self, proxy, gparamspec, data=None):
         self.update_icon()
 
@@ -189,6 +187,11 @@ class StatusWidget(Gtk.ToggleButton):
         return GLib.SOURCE_REMOVE
 
     def on_button_press(self, widget, event):
+        # If the user does ctrl->right-click, open the applet's about menu
+        # instead of sending to the app.
+        if event.state & Gdk.ModifierType.CONTROL_MASK and event.button == Gdk.BUTTON_SECONDARY:
+           return Gdk.EVENT_PROPAGATE
+
         orientation = translate_applet_orientation_to_xapp(self.orientation)
 
         x, y = self.calc_menu_origin(widget, orientation)
@@ -353,12 +356,21 @@ class MateXAppStatusApplet(object):
             indicator.orientation = orient
             indicator.update_orientation()
 
-        box_orientation = Gtk.Orientation.HORIZONTAL
-
         if orient in (MatePanelApplet.AppletOrient.LEFT, MatePanelApplet.AppletOrient.RIGHT):
-            box_orientation = Gtk.Orientation.VERTICAL
+            self.indicator_box.set_orientation(Gtk.Orientation.VERTICAL)
+
+            self.indicator_box.props.margin_start = 0
+            self.indicator_box.props.margin_end = 0
+            self.indicator_box.props.margin_top = 2
+            self.indicator_box.props.margin_bottom = 2
+        else:
+            self.indicator_box.set_orientation(Gtk.Orientation.HORIZONTAL)
+
+            self.indicator_box.props.margin_start = 2
+            self.indicator_box.props.margin_end = 2
+            self.indicator_box.props.margin_top = 0
+            self.indicator_box.props.margin_bottom = 0
 
-        self.indicator_box.set_orientation(box_orientation)
         self.indicator_box.queue_resize()
 
     def sort_icons(self):
